@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1501';
+our $VERSION = '0.1502';
 
 use MIDI::Simple;
 use Music::Duration;
@@ -301,10 +301,20 @@ sub crescendo_roll {
     my $x = $MIDI::Simple::Length{$length};
     my $y = $MIDI::Simple::Length{$spec};
     my $z = sprintf '%0.f', $x / $y;
+    my $v = sprintf '%0.f', ($j - $i) / ($z - 1);
+#    warn(__PACKAGE__,' ',__LINE__," VALUE: ",$v,"\n");
     for my $n (1 .. $z) {
-        #warn(__PACKAGE__,' ',__LINE__," MARK: ",$i,"\n");
+        if ($n == $z) {
+            if ($i < $j) {
+                $i += $j - $i;
+            }
+            elsif ($i > $j) {
+                $i -= $i - $j;
+            }
+        }
+#        warn(__PACKAGE__,' ',__LINE__," $n INC: ",$i,"\n");
         $self->accent_note($i, $spec, $patch);
-        $i += $j;
+        $i += $v;
     }
 }
 
@@ -345,7 +355,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1501
+version 0.1502
 
 =head1 SYNOPSIS
 
@@ -592,11 +602,11 @@ If not provided the B<snare> is used for the B<patch>.
 
 =head2 crescendo_roll
 
-  $d->crescendo_roll( [$start, $span], $length, $spec, $patch );
+  $d->crescendo_roll( [$i, $j], $length, $spec, $patch );
 
 Add a drum roll to the score, where the B<patch> is played for
 duration B<length> in B<spec> notes, at increasing or decreasing
-volumes from B<start> in B<span> increments.
+volumes from B<i> to B<j>.
 
 If not provided the B<snare> is used for the B<patch>.
 
